import apt_pkg
import os

apt_pkg.config["dir"] = os.path.abspath("root")
apt_pkg.init()

cache = apt_pkg.Cache()
depcache = apt_pkg.DepCache(cache)

for package in cache.packages:
    if package.essential and package.architecture == "amd64":
        depcache.mark_install(package, False)

resolver = apt_pkg.ProblemResolver(depcache)
for package in cache.packages:
    if depcache.marked_install(package):
        depcache.mark_install(package, True)
        resolver.protect(package)

resolver.resolve()

for package in sorted(cache.packages, key=lambda p: p.name):
    if not package.version_list:
        continue
    pid = os.fork()
    if pid == 0:
        depcache.mark_install(package)
        if depcache.broken_count > 0:
            resolver = apt_pkg.ProblemResolver(depcache)
            resolver.protect(package)
            try:
                resolver.resolve()
            except apt_pkg.Error:
                pass

        if depcache.broken_count > 0:
            broken = set()
            for otherpackage in cache.packages:
                if depcache.is_inst_broken(otherpackage):
                    broken.add(otherpackage.name)

            print(package.name + ":", "BAD:", " ".join(sorted(broken)))
        else:
            print(package.name + ":", "GOOD")
        os._exit(0)
    else:
        os.waitpid(pid, 0)
